@@ -72,6 +72,10 @@ namespace SPIRV {
 class LLVMToSPIRVBase : protected BuiltinCallHelper {
 public:
   LLVMToSPIRVBase(SPIRVModule *SMod);
+  LLVMToSPIRVBase(const LLVMToSPIRVBase &Other) = delete;
+  LLVMToSPIRVBase &operator=(const LLVMToSPIRVBase &Other) = delete;
+  LLVMToSPIRVBase(LLVMToSPIRVBase &&Other) = delete;
+  LLVMToSPIRVBase &operator=(LLVMToSPIRVBase &&Other) = delete;
   bool runLLVMToSPIRV(Module &Mod);
 
   // This enum sets the mode used to translate the value which is
@@ -134,7 +138,7 @@ public:
   void transFunctionMetadataAsExecutionMode(SPIRVFunction *BF, Function *F);
   void transFunctionMetadataAsUserSemanticDecoration(SPIRVFunction *BF,
                                                      Function *F);
-  void transAuxDataInst(SPIRVFunction *BF, Function *F);
+  void transAuxDataInst(SPIRVValue *BV, Value *V);
 
   bool transGlobalVariables();
 
